aboutsummaryrefslogtreecommitdiffstats
path: root/src/include/ipxe/infiniband.h
diff options
context:
space:
mode:
authorMichael Brown <mcb30@ipxe.org>2012-08-31 00:47:37 +0100
committerMichael Brown <mcb30@ipxe.org>2012-08-31 21:22:58 +0100
commitcbe41cb31be10edc234e96cf4291245c21272a57 (patch)
tree726646b6d2002dd10a3577ee120f8d27b5726484 /src/include/ipxe/infiniband.h
parentf747fac3e1dad31378579326d8e9dce0df85c214 (diff)
downloadipxe-cbe41cb31be10edc234e96cf4291245c21272a57.tar.gz
[infiniband] Use explicit "source" and "dest" address vector parameter names
Signed-off-by: Michael Brown <mcb30@ipxe.org>
Diffstat (limited to 'src/include/ipxe/infiniband.h')
-rw-r--r--src/include/ipxe/infiniband.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/include/ipxe/infiniband.h b/src/include/ipxe/infiniband.h
index 1a64eef6c..48c618875 100644
--- a/src/include/ipxe/infiniband.h
+++ b/src/include/ipxe/infiniband.h
@@ -205,13 +205,13 @@ struct ib_completion_queue_operations {
*
* @v ibdev Infiniband device
* @v qp Queue pair
* @v av Address vector, or NULL
* @v iobuf I/O buffer
* @v rc Completion status code
*/
void ( * complete_recv ) ( struct ib_device *ibdev,
struct ib_queue_pair *qp,
- struct ib_address_vector *av,
+ struct ib_address_vector *source,
struct io_buffer *iobuf, int rc );
};
@@ -289,7 +289,7 @@ struct ib_device_operations {
*
* @v ibdev Infiniband device
* @v qp Queue pair
* @v av Address vector
* @v iobuf I/O buffer
* @ret rc Return status code
*
@@ -300,7 +300,7 @@ struct ib_device_operations {
*/
int ( * post_send ) ( struct ib_device *ibdev,
struct ib_queue_pair *qp,
- struct ib_address_vector *av,
+ struct ib_address_vector *dest,
struct io_buffer *iobuf );
/** Post receive work queue entry
*
@@ -502,7 +502,7 @@ extern struct ib_queue_pair * ib_find_qp_mgid ( struct ib_device *ibdev,
extern struct ib_work_queue * ib_find_wq ( struct ib_completion_queue *cq,
unsigned long qpn, int is_send );
extern int ib_post_send ( struct ib_device *ibdev, struct ib_queue_pair *qp,
- struct ib_address_vector *av,
+ struct ib_address_vector *dest,
struct io_buffer *iobuf );
extern int ib_post_recv ( struct ib_device *ibdev, struct ib_queue_pair *qp,
struct io_buffer *iobuf );
@@ -511,7 +511,7 @@ extern void ib_complete_send ( struct ib_device *ibdev,
struct io_buffer *iobuf, int rc );
extern void ib_complete_recv ( struct ib_device *ibdev,
struct ib_queue_pair *qp,
- struct ib_address_vector *av,
+ struct ib_address_vector *source,
struct io_buffer *iobuf, int rc );
extern void ib_refill_recv ( struct ib_device *ibdev,
struct ib_queue_pair *qp );
@@ -205,13 +205,13 @@ struct ib_completion_queue_operations {
* @v ibdev Infiniband device
* @v qp Queue pair
- * @v av Address vector, or NULL
+ * @v source Source address vector, or NULL
* @v iobuf I/O buffer
* @v rc Completion status code
@@ -289,7 +289,7 @@ struct ib_device_operations {
* @v ibdev Infiniband device
* @v qp Queue pair
- * @v av Address vector
+ * @v dest Destination address vector
* @v iobuf I/O buffer
* @ret rc Return status code